@@ -1,15 +1,23 @@
 //! Token Owner Record Account
 
+use std::slice::Iter;
+
 use crate::{
+    addins::voter_weight::get_voter_weight_record_data_for_token_owner_record,
     error::GovernanceError,
-    state::{enums::GovernanceAccountType, governance::GovernanceConfig, realm::Realm},
+    state::{
+        enums::GovernanceAccountType, governance::GovernanceConfig, realm::Realm,
+        realm_config::get_realm_config_data_for_realm,
+    },
     tools::account::{get_account_data, AccountMaxSize},
     PROGRAM_AUTHORITY_SEED,
 };
 
 use borsh::{BorshDeserialize, BorshSchema, BorshSerialize};
 use solana_program::{
-    account_info::AccountInfo, program_error::ProgramError, program_pack::IsInitialized,
+    account_info::{next_account_info, AccountInfo},
+    program_error::ProgramError,
+    program_pack::IsInitialized,
     pubkey::Pubkey,
 };
 
@@ -95,8 +103,9 @@ impl TokenOwnerRecord {
         &self,
         realm_data: &Realm,
         config: &GovernanceConfig,
+        voter_weight: u64,
     ) -> Result<(), ProgramError> {
-        let min_tokens_to_create_proposal =
+        let min_weight_to_create_proposal =
             if self.governing_token_mint == realm_data.community_mint {
                 config.min_community_tokens_to_create_proposal
             } else if Some(self.governing_token_mint) == realm_data.config.council_mint {
@@ -105,13 +114,13 @@ impl TokenOwnerRecord {
                 return Err(GovernanceError::InvalidGoverningTokenMint.into());
             };
 
-        if self.governing_token_deposit_amount < min_tokens_to_create_proposal {
+        if voter_weight < min_weight_to_create_proposal {
             return Err(GovernanceError::NotEnoughTokensToCreateProposal.into());
         }
 
-        // The number of outstanding proposals is currently restricted to 1
+        // The number of outstanding proposals is currently restricted to 10
         // If there is a need to change it in the future then it should be added to realm or governance config
-        if self.outstanding_proposal_count > 0 {
+        if self.outstanding_proposal_count >= 10 {
             return Err(GovernanceError::TooManyOutstandingProposals.into());
         }
 
@@ -119,8 +128,12 @@ impl TokenOwnerRecord {
     }
 
     /// Asserts TokenOwner has enough tokens to be allowed to create governance
-    pub fn assert_can_create_governance(&self, realm_data: &Realm) -> Result<(), ProgramError> {
-        let min_tokens_to_create_governance =
+    pub fn assert_can_create_governance(
+        &self,
+        realm_data: &Realm,
+        voter_weight: u64,
+    ) -> Result<(), ProgramError> {
+        let min_weight_to_create_governance =
             if self.governing_token_mint == realm_data.community_mint {
                 realm_data.config.min_community_tokens_to_create_governance
             } else if Some(self.governing_token_mint) == realm_data.config.council_mint {
@@ -130,13 +143,30 @@ impl TokenOwnerRecord {
                 return Err(GovernanceError::InvalidGoverningTokenMint.into());
             };
 
-        if self.governing_token_deposit_amount < min_tokens_to_create_governance {
+        if voter_weight < min_weight_to_create_governance {
             return Err(GovernanceError::NotEnoughTokensToCreateGovernance.into());
         }
 
         Ok(())
     }
 
+    /// Asserts TokenOwner can withdraw tokens from Realm
+    pub fn assert_can_withdraw_governing_tokens(&self) -> Result<(), ProgramError> {
+        if self.unrelinquished_votes_count > 0 {
+            return Err(
+                GovernanceError::AllVotesMustBeRelinquishedToWithdrawGoverningTokens.into(),
+            );
+        }
+
+        if self.outstanding_proposal_count > 0 {
+            return Err(
+                GovernanceError::AllProposalsMustBeFinalisedToWithdrawGoverningTokens.into(),
+            );
+        }
+
+        Ok(())
+    }
+
     /// Decreases outstanding_proposal_count
     pub fn decrease_outstanding_proposal_count(&mut self) {
         // Previous versions didn't use the count and it can be already 0
@@ -146,6 +176,36 @@ impl TokenOwnerRecord {
                 self.outstanding_proposal_count.checked_sub(1).unwrap();
         }
     }
+
+    /// Resolves voter's weight using either the amount deposited into the realm or weight provided by voter weight addin (if configured)
+    pub fn resolve_voter_weight(
+        &self,
+        program_id: &Pubkey,
+        account_info_iter: &mut Iter<AccountInfo>,
+        realm: &Pubkey,
+        realm_data: &Realm,
+    ) -> Result<u64, ProgramError> {
+        // if the realm uses addin for community voter weight then use the externally provided weight
+        if realm_data.config.use_community_voter_weight_addin
+            && realm_data.community_mint == self.governing_token_mint
+        {
+            let realm_config_info = next_account_info(account_info_iter)?;
+            let voter_weight_record_info = next_account_info(account_info_iter)?;
+
+            let realm_config_data =
+                get_realm_config_data_for_realm(program_id, realm_config_info, realm)?;
+
+            let voter_weight_record_data = get_voter_weight_record_data_for_token_owner_record(
+                &realm_config_data.community_voter_weight_addin.unwrap(),
+                voter_weight_record_info,
+                self,
+            )?;
+            voter_weight_record_data.assert_is_up_to_date()?;
+            Ok(voter_weight_record_data.voter_weight)
+        } else {
+            Ok(self.governing_token_deposit_amount)
+        }
+    }
 }
 
 /// Returns TokenOwnerRecord PDA address
