@@ -21,7 +21,8 @@ async fn test_cast_vote() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -37,7 +38,7 @@ async fn test_cast_vote() {
         .await
         .unwrap();
 
-    let clock = governance_test.get_clock().await;
+    let clock = governance_test.bench.get_clock().await;
 
     // Act
     let vote_record_cookie = governance_test
@@ -98,7 +99,8 @@ async fn test_cast_vote_with_invalid_governance_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -148,7 +150,8 @@ async fn test_cast_vote_with_invalid_mint_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -188,7 +191,8 @@ async fn test_cast_vote_with_invalid_token_owner_record_mint_error() {
 
     let mut token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -207,7 +211,8 @@ async fn test_cast_vote_with_invalid_token_owner_record_mint_error() {
     // Try to use token_owner_record for Council Mint with Community Proposal
     let token_owner_record_cookie2 = governance_test
         .with_council_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     token_owner_record_cookie.address = token_owner_record_cookie2.address;
 
@@ -234,7 +239,8 @@ async fn test_cast_vote_with_invalid_token_owner_record_from_different_realm_err
 
     let mut token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -255,7 +261,8 @@ async fn test_cast_vote_with_invalid_token_owner_record_from_different_realm_err
 
     let token_owner_record_cookie2 = governance_test
         .with_community_token_deposit(&realm_cookie2)
-        .await;
+        .await
+        .unwrap();
 
     token_owner_record_cookie.address = token_owner_record_cookie2.address;
 
@@ -279,7 +286,8 @@ async fn test_cast_vote_with_governance_authority_must_sign_error() {
 
     let mut token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -298,7 +306,8 @@ async fn test_cast_vote_with_governance_authority_must_sign_error() {
     // Try to use a different owner to sign
     let token_owner_record_cookie2 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     token_owner_record_cookie.token_owner = token_owner_record_cookie2.token_owner;
 
@@ -325,7 +334,8 @@ async fn test_cast_vote_with_vote_tipped_to_succeeded() {
 
     let token_owner_record_cookie1 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -338,11 +348,13 @@ async fn test_cast_vote_with_vote_tipped_to_succeeded() {
 
     let token_owner_record_cookie2 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let token_owner_record_cookie3 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     governance_test
         .mint_community_tokens(&realm_cookie, 20)
@@ -413,7 +425,8 @@ async fn test_cast_vote_with_vote_tipped_to_defeated() {
     // 100 votes
     let token_owner_record_cookie1 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -427,12 +440,14 @@ async fn test_cast_vote_with_vote_tipped_to_defeated() {
     // 100 votes
     let token_owner_record_cookie2 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     // 100 votes
     let token_owner_record_cookie3 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     // Total 320 votes
     governance_test
@@ -507,7 +522,8 @@ async fn test_cast_vote_with_threshold_below_50_and_vote_not_tipped() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance_using_config(
@@ -560,7 +576,8 @@ async fn test_cast_vote_with_voting_time_expired_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
@@ -610,7 +627,8 @@ async fn test_cast_vote_with_cast_twice_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut account_governance_cookie = governance_test
         .with_account_governance(
