@@ -18,7 +18,8 @@ async fn test_create_mint_governance() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     // Act
     let mint_governance_cookie = governance_test
@@ -57,7 +58,8 @@ async fn test_create_mint_governance_without_transferring_mint_authority() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     governed_mint_cookie.transfer_mint_authority = false;
     // Act
@@ -98,7 +100,8 @@ async fn test_create_mint_governance_without_transferring_mint_authority_with_in
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     governed_mint_cookie.transfer_mint_authority = false;
     governed_mint_cookie.mint_authority = Keypair::new();
@@ -129,7 +132,8 @@ async fn test_create_mint_governance_without_transferring_mint_authority_with_au
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     governed_mint_cookie.transfer_mint_authority = false;
 
@@ -142,7 +146,7 @@ async fn test_create_mint_governance_without_transferring_mint_authority_with_au
             |i| {
                 i.accounts[3].is_signer = false; // governed_mint_authority
             },
-            Some(&[]),
+            Some(&[&token_owner_record_cookie.token_owner]),
         )
         .await
         .err()
@@ -162,7 +166,8 @@ async fn test_create_mint_governance_with_invalid_mint_authority_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     governed_mint_cookie.mint_authority = Keypair::new();
 
@@ -191,7 +196,8 @@ async fn test_create_mint_governance_with_invalid_realm_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mint_governance_cookie = governance_test
         .with_mint_governance(
