@@ -1,4 +1,4 @@
-#![cfg(feature = "test-bpf-all")]
+#![cfg(feature = "test-bpf")]
 
 mod program_test;
 
@@ -26,7 +26,8 @@ async fn test_execute_mint_instruction() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut mint_governance_cookie = governance_test
         .with_mint_governance(
@@ -72,7 +73,7 @@ async fn test_execute_mint_instruction() {
         .advance_clock_by_min_timespan(proposal_instruction_cookie.account.hold_up_time as u64)
         .await;
 
-    let clock = governance_test.get_clock().await;
+    let clock = governance_test.bench.get_clock().await;
 
     // Act
     governance_test
@@ -122,7 +123,8 @@ async fn test_execute_transfer_instruction() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut token_governance_cookie = governance_test
         .with_token_governance(
@@ -168,7 +170,7 @@ async fn test_execute_transfer_instruction() {
         .advance_clock_by_min_timespan(proposal_instruction_cookie.account.hold_up_time as u64)
         .await;
 
-    let clock = governance_test.get_clock().await;
+    let clock = governance_test.bench.get_clock().await;
 
     // Act
     governance_test
@@ -218,7 +220,8 @@ async fn test_execute_upgrade_program_instruction() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut program_governance_cookie = governance_test
         .with_program_governance(
@@ -275,6 +278,7 @@ async fn test_execute_upgrade_program_instruction() {
     );
 
     let err = governance_test
+        .bench
         .process_transaction(&[governed_program_instruction.clone()], None)
         .await
         .err()
@@ -283,7 +287,7 @@ async fn test_execute_upgrade_program_instruction() {
     // solana_bpf_rust_upgradable returns CustomError == 42
     assert_eq!(ProgramError::Custom(42), err);
 
-    let clock = governance_test.get_clock().await;
+    let clock = governance_test.bench.get_clock().await;
 
     // Act
     governance_test
@@ -321,6 +325,7 @@ async fn test_execute_upgrade_program_instruction() {
     governance_test.advance_clock().await;
 
     let err = governance_test
+        .bench
         .process_transaction(&[governed_program_instruction.clone()], None)
         .await
         .err()
@@ -342,7 +347,8 @@ async fn test_execute_instruction_with_invalid_state_errors() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut mint_governance_cookie = governance_test
         .with_mint_governance(
@@ -504,7 +510,8 @@ async fn test_execute_instruction_for_other_proposal_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut mint_governance_cookie = governance_test
         .with_mint_governance(
@@ -553,13 +560,16 @@ async fn test_execute_instruction_for_other_proposal_error() {
 
     let token_owner_record_cookie2 = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let proposal_cookie2 = governance_test
         .with_proposal(&token_owner_record_cookie2, &mut mint_governance_cookie)
         .await
         .unwrap();
 
+    governance_test.advance_clock().await;
+
     // Act
     let err = governance_test
         .execute_instruction(&proposal_cookie2, &proposal_instruction_cookie)
@@ -584,7 +594,8 @@ async fn test_execute_mint_instruction_twice_error() {
 
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
-        .await;
+        .await
+        .unwrap();
 
     let mut mint_governance_cookie = governance_test
         .with_mint_governance(
